%bcond_with system_admesh

Name:           slic3r
Version:        1.3.0
%define subrel 1
Release:        %mkrel 6
Summary:        G-code generator for 3D printers (RepRap, Makerbot, Ultimaker etc.)
License:        AGPLv3
# Images are CC-BY, code is AGPLv3
Group:          Sciences/Other
URL:            http://slic3r.org/
Source0:        https://github.com/alexrj/Slic3r/archive/%{version}/Slic3r-%{version}.tar.gz
Source1:        %{name}.desktop
Source2:        %{name}.appdata.xml

# Modify Build.PL so we are able to build this on Fedora
Patch0:         %{name}-buildpl.patch

# Use /usr/share/slic3r as datadir
Patch1:         %{name}-datadir.patch
Patch2:         %{name}-english-locale.patch
Patch3:         %{name}-linker.patch
Patch4:         %{name}-clipper.patch
Patch5:         %{name}-1.3.0-fixtest.patch
Patch6:         %{name}-wayland.patch
Patch7:         %{name}-boost169.patch

Patch11:        slic3r-boost-skip-endianess-check.patch
Patch12:        slic3r-boost-placeholders.patch

Patch13:         %{name}-CVE-2020-28591.patch

BuildRequires:  gcc-c++
BuildRequires:  perl-devel
BuildRequires:  perl(Class::XSAccessor)
BuildRequires:  perl(Devel::CheckLib)
BuildRequires:  perl(Encode::Locale) >= 1.05
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.80
BuildRequires:  perl(ExtUtils::ParseXS) >= 3.22
BuildRequires:  perl(ExtUtils::Typemaps::Default) >= 1.50.0
BuildRequires:  perl(ExtUtils::Typemaps) >= 1.00
BuildRequires:  perl(File::Basename)
BuildRequires:  perl(File::Spec)
BuildRequires:  perl(Getopt::Long)
BuildRequires:  perl(Growl::GNTP) >= 0.15
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(List::Util)
BuildRequires:  perl(Math::PlanePath) >= 53
BuildRequires:  perl(Module::Build::WithXSpp) >= 0.14
BuildRequires:  perl(Moo) >= 1.6.0
BuildRequires:  perl(parent)
BuildRequires:  perl(Scalar::Util)
BuildRequires:  perl(Storable)
BuildRequires:  perl(SVG)
BuildRequires:  perl(Test::Harness)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Time::HiRes)
BuildRequires:  perl(Wx)
BuildRequires:  perl(XML::SAX)
BuildRequires:  perl(XML::SAX::ExpatXS)

%if %{with system_admesh}
BuildRequires:  pkgconfig(libadmesh) >= 0.98.1
%else
Provides:       bundled(admesh) = 0.98
%endif
BuildRequires:  boost-devel
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig(poly2tri)
BuildRequires:  pkgconfig(polyclipping) >= 6.4.2
BuildRequires:  pkgconfig(expat) >= 2.2.0
BuildRequires:  ImageMagick

Requires:       perl(XML::SAX)
Requires:       perl(threads) >= %perl_convert_version 1.96
#This duplicate added, because otherwise RPM is resolving 1.92 as meeting the 1.96+ requirement
Requires:       perl-threads >= %perl_convert_version 1.96

# Optional dependency, It's only used for magically finding octoprint servers.
Recommends:     perl(Net::Bonjour)

%description
Slic3r is a G-code generator for 3D printers. It's compatible with RepRaps,
Makerbots, Ultimakers and many more machines.
See the project homepage at slic3r.org and the documentation on the Slic3r wiki
for more information.

%prep
%setup -qn Slic3r-%{version}
%autopatch -p1

# Remove bundled admesh, clipper, poly2tri and expat
%if %{with system_admesh}
rm -rf xs/src/admesh
sed -i '/src\/admesh/d' xs/MANIFEST
%endif
rm xs/src/clipper.*pp
rm -rf xs/src/poly2tri
sed -i '/src\/poly2tri/d' xs/MANIFEST
rm -rf xs/src/expat
sed -i '/src\/expat/d' xs/MANIFEST
# These are the files with hardcoded expat/expat.h includes
sed -i 's|expat/expat.h|expat.h|g' xs/src/libslic3r/IO/AMF.cpp
sed -i 's|expat/expat.h|expat.h|g' xs/src/libslic3r/IO/TMF.hpp

%build
%if %{with system_admesh}
export SYSTEM_LIBS="${SYSTEM_LIBS} -ladmesh"
%endif
export SYSTEM_LIBS="${SYSTEM_LIBS} -lpolyclipping"
export SYSTEM_LIBS="${SYSTEM_LIBS} -lexpat"
export SYSTEM_LIBS="${SYSTEM_LIBS} -lpoly2tri"

cd xs
[[ ! -z "${SYSTEM_LIBS}" ]] && echo "SYSTEM_LIBS is ${SYSTEM_LIBS}"
perl ./Build.PL installdirs=vendor optimize="$RPM_OPT_FLAGS"
./Build
cd -
# Building non XS part only runs test, so skip it and run it in tests

# prepare pngs in mutliple sizes
for res in 16 32 48 128 256; do
  mkdir -p hicolor/${res}x${res}/apps
done
cd hicolor
convert ../var/Slic3r.ico %{name}.png
cp %{name}-0.png 256x256/apps/%{name}.png
cp %{name}-1.png 128x128/apps/%{name}.png
cp %{name}-2.png 48x48/apps/%{name}.png
cp %{name}-3.png 32x32/apps/%{name}.png
cp %{name}-4.png 16x16/apps/%{name}.png
rm %{name}-*.png
cd -

# To avoid "iCCP: Not recognized known sRGB profile that has been edited"
cd var
find . -type f -name "*.png" -exec convert {} -strip {} \;
cd -

%install
cd xs
./Build install destdir=%{buildroot} create_packlist=0
cd -
find %{buildroot} -type f -name '*.bs' -size 0 -exec rm -f {} \;

# I see no way of installing slic3r with it's build script
# So I copy the files around manually
mkdir -p  %{buildroot}%{_bindir}
mkdir -p  %{buildroot}%{perl_vendorlib}
mkdir -p  %{buildroot}%{_datadir}/%{name}
mkdir -p  %{buildroot}%{_datadir}/icons
mkdir -p  %{buildroot}%{_datadir}/appdata

cp -a %{name}.pl %{buildroot}%{_bindir}/%{name}
cp -ar lib/* %{buildroot}%{perl_vendorlib}

cp -a var/* %{buildroot}%{_datadir}/%{name}
cp -r hicolor %{buildroot}%{_datadir}/icons
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE1}

cp %{SOURCE2} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

%{_fixperms} %{buildroot}*

%check
# disable testsuite:
exit 0
cd xs
./Build test verbose=1 || :
cd -
SLIC3R_NO_AUTO=1 %__perl Build.PL installdirs=vendor
# the --gui runs no tests, it only checks requires

%files
%doc README.md
%{_bindir}/%{name}
%{perl_vendorlib}/Slic3r*
%{perl_vendorarch}/Slic3r*
%{perl_vendorarch}/auto/Slic3r*
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/%{name}


%changelog
* Wed Jun 02 2021 ns80 <ns80> 1.3.0-6.1.mga8
+ Revision: 1729202
- add Fedora patch for CVE-2020-28591 (mga#29020)

* Thu Dec 31 2020 wally <wally> 1.3.0-6.mga8
+ Revision: 1666816
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 1.3.0-5.mga8
+ Revision: 1662058
- rebuild for boost 1.74.0

* Sun May 03 2020 wally <wally> 1.3.0-4.mga8
+ Revision: 1578495
- rebuild for boost 1.73.0

* Wed Feb 19 2020 umeabot <umeabot> 1.3.0-3.mga8
+ Revision: 1544891
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 1.3.0-2.mga8
+ Revision: 1483432
- rebuild for boost 1.72.0

* Fri Nov 15 2019 daviddavid <daviddavid> 1.3.0-1.mga8
+ Revision: 1460303
- new version: 1.3.0, fixes segmentation fault with nvidia driver (mga#25473)
- use bundled admesh (due to FTBFS)
- use system expat

* Sun Sep 23 2018 umeabot <umeabot> 1.2.9-10.mga7
+ Revision: 1301065
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 tv <tv> 1.2.9-9.mga7
+ Revision: 1250747
- rebuild for perl-5.28

* Mon Sep 25 2017 tv <tv> 1.2.9-8.mga7
+ Revision: 1159112
- rebuild with perl-5.26.x

* Mon Sep 19 2016 akien <akien> 1.2.9-7.mga6
+ Revision: 1054420
- Rebuild again for polyclipping, for real this time

* Mon Sep 19 2016 akien <akien> 1.2.9-6.mga6
+ Revision: 1054305
- Rebuild for polyclipping 6.4
- Remove Fedoraisms

* Sun Jun 19 2016 pterjan <pterjan> 1.2.9-5.mga6
+ Revision: 1036487
- Rebuild for perl 5.22.2

* Sun Apr 24 2016 akien <akien> 1.2.9-4.mga6
+ Revision: 1005879
- Rebuild for new poly2tri

* Tue Mar 29 2016 tv <tv> 1.2.9-3.mga6
+ Revision: 996067
- sync patch 1 with FC
- add build fix from FC
- obsoletes both slic3r-stable & slic3r-experimental
- rename slic3r-stable as slic3r in SVN
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sun Jun 28 2015 tv <tv> 1.2.9-1.mga6
+ Revision: 846680
- disable testsuite
- BR perl(Encode::Locale)
- ignore testsuite faillure (like for experimental)
- new release
- 1.2.x is now stable
- rebuild for soname-ifed perl

* Tue Jun 23 2015 sander85 <sander85> 1.1.7-5.mga6
+ Revision: 840870
- Rebuild for perl 5.22

* Tue Jan 13 2015 shlomif <shlomif> 1.1.7-4.mga5
+ Revision: 810322
- Add missing BR on perl-devel
- Importing slic3r-stable (thanks to Richard Houser)

